powered by
View the prior distributions that are applied by default when using a given measurement and structural model.
default_dcm_priors(measurement_model = NULL, structural_model = NULL)
A dcmprior object.
dcmprior
A measurement model object.
A structural model object.
default_dcm_priors(lcdm(), unconstrained()) default_dcm_priors(dina(), independent()) default_dcm_priors(lcdm(), loglinear())
Run the code above in your browser using DataLab